@@ -6,6 +6,8 @@ if [ -n "${EZ_VERBOSE}" ]; then
     set -x
 fi
 
+USE_TASKSMAX=${USE_TASKSMAX:-true}
+
 # Warning: This variable API is experimental so these variables may be subject
 # to change in the future.
 prefix=${prefix:=/usr}
@@ -140,8 +142,8 @@ function task_install_docs_deb {
 # install docs for rpm based systems
 function task_install_docs_rpm {
   if [ -d ext/docs ]; then
-    install -d "${DESTDIR}${app_prefix}/share/doc/puppetdb-5.1.1"
-    cp -a ext/docs "${DESTDIR}${app_prefix}/share/doc/puppetdb-5.1.1"
+    install -d "${DESTDIR}${app_prefix}/share/doc/puppetdb-7.13.0"
+    cp -a ext/docs "${DESTDIR}${app_prefix}/share/doc/puppetdb-7.13.0"
   fi
 }
 
@@ -157,11 +159,12 @@ function task_install {
 
   
 
-    install -m 0644 ext/config/bootstrap.cfg "${DESTDIR}${projconfdir}/bootstrap.cfg"
-    install -m 0644 ext/config/conf.d/config.ini "${DESTDIR}${projconfdir}/conf.d/config.ini"
     install -m 0644 ext/config/conf.d/database.ini "${DESTDIR}${projconfdir}/conf.d/database.ini"
-    install -m 0644 ext/config/conf.d/jetty.ini "${DESTDIR}${projconfdir}/conf.d/jetty.ini"
+    install -m 0644 ext/config/conf.d/auth.conf "${DESTDIR}${projconfdir}/conf.d/auth.conf"
+    install -m 0644 ext/config/conf.d/config.ini "${DESTDIR}${projconfdir}/conf.d/config.ini"
     install -m 0644 ext/config/conf.d/repl.ini "${DESTDIR}${projconfdir}/conf.d/repl.ini"
+    install -m 0644 ext/config/conf.d/jetty.ini "${DESTDIR}${projconfdir}/conf.d/jetty.ini"
+    install -m 0644 ext/config/bootstrap.cfg "${DESTDIR}${projconfdir}/bootstrap.cfg"
     install -m 0644 ext/config/logback.xml "${DESTDIR}${projconfdir}/logback.xml"
     install -m 0644 ext/config/request-logging.xml "${DESTDIR}${projconfdir}/request-logging.xml"
 
@@ -176,13 +179,14 @@ function task_install {
     ln -s "../apps/${real_name}/bin/${real_name}" "${DESTDIR}${symbindir}/${real_name}"
     install -d -m 0755 "${DESTDIR}${uxbindir}"
     ln -s "../server/apps/${real_name}/bin/${real_name}" "${DESTDIR}${uxbindir}/${real_name}"
-    install -m 0755 ext/cli/foreground "${dest_apps_dir}/cli/apps/foreground"
-    install -m 0755 ext/cli/reload "${dest_apps_dir}/cli/apps/reload"
     install -m 0755 ext/cli/stop "${dest_apps_dir}/cli/apps/stop"
-    install -m 0755 ext/cli/start "${dest_apps_dir}/cli/apps/start"
     install -m 0755 ext/cli/anonymize "${dest_apps_dir}/cli/apps/anonymize"
-    install -m 0755 ext/cli/config-migration "${dest_apps_dir}/cli/apps/config-migration"
     install -m 0755 ext/cli/foreground "${dest_apps_dir}/cli/apps/foreground"
+    install -m 0755 ext/cli/upgrade "${dest_apps_dir}/cli/apps/upgrade"
+    install -m 0755 ext/cli/reload "${dest_apps_dir}/cli/apps/reload"
+    install -m 0755 ext/cli/config-migration "${dest_apps_dir}/cli/apps/config-migration"
+    install -m 0755 ext/cli/delete-reports "${dest_apps_dir}/cli/apps/delete-reports"
+    install -m 0755 ext/cli/start "${dest_apps_dir}/cli/apps/start"
     install -m 0755 ext/cli/ssl-setup "${dest_apps_dir}/cli/apps/ssl-setup"
 
 if [ -e "ext/cli_defaults/cli-defaults.sh" ]; then
@@ -211,23 +215,23 @@ function task_termini {
     #
     # This also allows us to prefer PE ruby over system ruby, so this will work
     # with PE as well
-    local rubylibdir=${rubylibdir:=$(/opt/puppetlabs/puppet/bin/ruby -rrbconfig -e "puts RbConfig::CONFIG['vendordir']")}
-    install -Dm 0644 puppet/face/node/deactivate.rb "${DESTDIR}${rubylibdir}/puppet/face/node/deactivate.rb"
-    install -Dm 0644 puppet/face/node/status.rb "${DESTDIR}${rubylibdir}/puppet/face/node/status.rb"
+    local rubylibdir=${rubylibdir:=/opt/puppetlabs/puppet/lib/ruby/vendor_ruby}
     install -Dm 0644 puppet/functions/puppetdb_query.rb "${DESTDIR}${rubylibdir}/puppet/functions/puppetdb_query.rb"
+    install -Dm 0644 puppet/face/node/status.rb "${DESTDIR}${rubylibdir}/puppet/face/node/status.rb"
+    install -Dm 0644 puppet/face/node/deactivate.rb "${DESTDIR}${rubylibdir}/puppet/face/node/deactivate.rb"
     install -Dm 0644 puppet/indirector/catalog/puppetdb.rb "${DESTDIR}${rubylibdir}/puppet/indirector/catalog/puppetdb.rb"
+    install -Dm 0644 puppet/indirector/resource/puppetdb.rb "${DESTDIR}${rubylibdir}/puppet/indirector/resource/puppetdb.rb"
     install -Dm 0644 puppet/indirector/facts/puppetdb.rb "${DESTDIR}${rubylibdir}/puppet/indirector/facts/puppetdb.rb"
     install -Dm 0644 puppet/indirector/facts/puppetdb_apply.rb "${DESTDIR}${rubylibdir}/puppet/indirector/facts/puppetdb_apply.rb"
     install -Dm 0644 puppet/indirector/node/puppetdb.rb "${DESTDIR}${rubylibdir}/puppet/indirector/node/puppetdb.rb"
-    install -Dm 0644 puppet/indirector/resource/puppetdb.rb "${DESTDIR}${rubylibdir}/puppet/indirector/resource/puppetdb.rb"
-    install -Dm 0644 puppet/reports/puppetdb.rb "${DESTDIR}${rubylibdir}/puppet/reports/puppetdb.rb"
     install -Dm 0644 puppet/util/puppetdb.rb "${DESTDIR}${rubylibdir}/puppet/util/puppetdb.rb"
-    install -Dm 0644 puppet/util/puppetdb/atom.rb "${DESTDIR}${rubylibdir}/puppet/util/puppetdb/atom.rb"
-    install -Dm 0644 puppet/util/puppetdb/char_encoding.rb "${DESTDIR}${rubylibdir}/puppet/util/puppetdb/char_encoding.rb"
     install -Dm 0644 puppet/util/puppetdb/command.rb "${DESTDIR}${rubylibdir}/puppet/util/puppetdb/command.rb"
+    install -Dm 0644 puppet/util/puppetdb/atom.rb "${DESTDIR}${rubylibdir}/puppet/util/puppetdb/atom.rb"
     install -Dm 0644 puppet/util/puppetdb/command_names.rb "${DESTDIR}${rubylibdir}/puppet/util/puppetdb/command_names.rb"
     install -Dm 0644 puppet/util/puppetdb/config.rb "${DESTDIR}${rubylibdir}/puppet/util/puppetdb/config.rb"
+    install -Dm 0644 puppet/util/puppetdb/char_encoding.rb "${DESTDIR}${rubylibdir}/puppet/util/puppetdb/char_encoding.rb"
     install -Dm 0644 puppet/util/puppetdb/http.rb "${DESTDIR}${rubylibdir}/puppet/util/puppetdb/http.rb"
+    install -Dm 0644 puppet/reports/puppetdb.rb "${DESTDIR}${rubylibdir}/puppet/reports/puppetdb.rb"
 }
 
 function task_defaults_redhat {
@@ -276,6 +280,9 @@ function task_systemd_deb {
     task sysv_init_deb
     install -d -m 0755 "${DESTDIR}${unitdir_debian}"
     install -m 0644 ext/debian/puppetdb.service_file "${DESTDIR}${unitdir_debian}/puppetdb.service"
+    if [ "$USE_TASKSMAX" == "false" ]; then
+      sed -i "s/^TasksMax/# Don't set TasksMax since the option doesn't exist\n# TasksMax/" "${DESTDIR}${unitdir_debian}/puppetdb.service"
+    fi
     install -d -m 0755 "${DESTDIR}${tmpfilesdir}"
     install -m 0644 ext/puppetdb.tmpfiles.conf "${DESTDIR}${tmpfilesdir}/puppetdb.conf"
 }
@@ -300,7 +307,9 @@ function task_service_account {
 # section of an rpm/deb.
 function task_preinst_redhat {
     task service_account
-    if rpm -q puppetdb | grep ^puppetdb-2.* > /dev/null && [ $1 -eq 2 ] ; then tar -czf /tmp/puppetdb-upgrade-config-files.tgz -C /etc/puppetdb/conf.d config.ini database.ini jetty.ini ; fi
+    if rpm -q puppetdb | grep '^puppetdb-2.*' > /dev/null && [ "$1" -eq 2 ]; then
+        tar -czf /tmp/puppetdb-upgrade-config-files.tgz -C /etc/puppetdb/conf.d config.ini database.ini jetty.ini
+    fi
 }
 
 # Debian based pre-installation tasks.
@@ -309,21 +318,55 @@ function task_preinst_redhat {
 # section of an rpm/deb.
 function task_preinst_deb {
     task service_account
-    if [ $1 = 'upgrade' ] && [ ${2%%.*} -le 2 ] ; then tar -czf /tmp/puppetdb-upgrade-config-files.tgz -C /etc/puppetdb/conf.d config.ini database.ini jetty.ini ; fi
+    if [ "$1" = upgrade ] && [ "${2%%.*}" -le 2 ] ; then tar -czf /tmp/puppetdb-upgrade-config-files.tgz -C /etc/puppetdb/conf.d config.ini database.ini jetty.ini ; fi
 }
 
-# Debian based post-installation tasks.
+# Debian based unconditional post-installation tasks.
 function task_postinst_deb {
     task postinst_permissions
     /opt/puppetlabs/server/bin/puppetdb config-migration
     /opt/puppetlabs/server/bin/puppetdb ssl-setup
 }
 
-# RPM based post-installation tasks.
+# Debian based install post-installation tasks.
+function task_postinst_deb_install {
+    : # Null command in case additional_postinst_install is empty
+}
+
+# RPM based unconditional post-installation tasks.
 function task_postinst_redhat {
     : # Null command in case additional_postinst is empty
     /opt/puppetlabs/server/bin/puppetdb config-migration
     /opt/puppetlabs/server/bin/puppetdb ssl-setup
+    
+    # puppetdb changed its main namespace in 6.3 and the current rpm
+    # upgrade strategy fails to restart the server correctly because
+    # it ends up using the templated stop from the new package which 
+    # refers to the wrong namespace for the older pdb that's still
+    # running.  Kill the old pdb if found and start the new one.
+    # These changes can be removed in PuppetDB version 8.
+    (maybe_dead=''
+     pid="$(pgrep -f "puppetdb.* -m puppetlabs.puppetdb.main")"
+     if test $? -eq 0; then
+         kill "$pid" 2>/dev/null
+         for i in {1..75}; do  # Wait up to ~15s
+             if kill -0 "$pid" 2>/dev/null; then
+                 maybe_dead=1
+                 break
+             fi
+             sleep 0.2
+         done
+         if test -z "$maybe_dead"; then
+             echo 'Unable to kill puppetdb server cleanly; sending KILL' 1>&2
+             kill -9 "$pid"
+         fi
+         /sbin/service puppetdb start > /dev/null 2>&1
+     fi)
+}
+
+# RPM based install post-installation tasks.
+function task_postinst_redhat_install {
+    : # Null command in case additional_postinst_install is empty
 }
 
 # Global post installation permissions setup. Not to be used by Redhat
