@@ -28,7 +28,8 @@
             [puppetlabs.trapperkeeper.logging :refer [configure-logging!]]
             [clojure.tools.logging :as log]
             [schema.core :as schema]
-            [puppetlabs.trapperkeeper.common :as common]))
+            [puppetlabs.trapperkeeper.common :as common]
+            [puppetlabs.i18n.core :as i18n]))
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;; Service protocol
@@ -57,7 +58,21 @@
     (edn/read (PushbackReader. (io/reader file)))
 
     #{".yaml" ".yml"}
-    (yaml/parse-string (slurp file))))
+    (yaml/parse-string (slurp file))
+
+    (throw (IllegalArgumentException.
+            (i18n/trs "Config file {0} must end in .conf or other recognized extension"
+                      (-> file str pr-str))))))
+
+(defn override-restart-file-from-cli-data
+  [config-data cli-data]
+  (if-let [cli-restart-file (:restart-file cli-data)]
+    (do
+      (if (get-in config-data [:global :restart-file])
+        (log/warnf (i18n/trs "restart-file setting specified both on command-line and in config file, using command-line value: ''{0}''"
+                             cli-restart-file)))
+      (assoc-in config-data [:global :restart-file] cli-restart-file))
+    config-data))
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;; Public
@@ -68,8 +83,8 @@
   [path]
   (when-not (.canRead (io/file path))
     (throw (FileNotFoundException.
-            (format "Configuration path '%s' must exist and must be readable."
-                    path))))
+             (i18n/trs "Configuration path ''{0}'' must exist and must be readable."
+                       path))))
   (if-not (fs/directory? path)
     [path]
     (mapcat
@@ -89,7 +104,7 @@
          (apply ks/deep-merge-with-keys
                 (fn [ks & _]
                   (throw (IllegalArgumentException.
-                          (str "Duplicate configuration entry: " ks)))))
+                           (i18n/trs "Duplicate configuration entry: {0}" ks)))))
          (merge {}))))
 
 (defn config-service
@@ -122,7 +137,8 @@
       {:debug debug?}
       (-> (:config cli-data)
           (load-config)
-          (assoc :debug debug?)))))
+          (assoc :debug debug?)
+          (override-restart-file-from-cli-data cli-data)))))
 
 (defn initialize-logging!
   "Initializes the logging system based on the configuration data."
